==> ember-cli-group-by-0.0.8.tgz: package/CHANGELOG.md <==
# Change Log

## [v0.0.8](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.7) (2018-07-03)

- Update ember-cli@3.2.0 and ember-source@3.2.0.
- Update dev dependencies.
- Remove `bower.json`.

## [v0.0.7](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.7) (2018-07-03)

- Unpublished because tarball was shipped with Webstorm .idea folder.

## [v0.0.6](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.6) (2018-05-07)

- Upgrade to ember-source 3.1.0 and dev dependencies. 

## [v0.0.5](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.5) (2018-03-06)

- Add new group by computed property.
- Private nested computed properties do not fire when changes made in array. [\#1](https://github.com/scottwernervt/ember-cli-group-by/issues/1)

## [v0.0.4](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.4) (2017-12-01)

- Upgrade to ember-cli@2.17.0 and ember-source@2.17.0.

## [v0.0.3](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.3) (2017-08-22)

- Upgrade to ember-cli@2.14.2 and ember-source@2.14.1.
- Use new module import code style.Upgrade ember-cli@2.17.0 and ember-source@2.17.0Upgrade ember-cli@2.17.0 and ember-source@2.17.0

## [v0.0.2](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.2) (2017-05-24)

- Remove `ember-data` as a dependency.
- Add async nested path integration tests.

## [v0.0.1](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.1) (2017-05-23)

- Missing (default) category does not work for async relationships. [\#3](https://github.com/scottwernervt/ember-cli-group-by/issues/3)

==> ember-cli-group-by-0.0.10.tgz: package/CHANGELOG.md <==
# Change Log

## [v0.0.10](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.10) (2018-11-14)

- Upgrade to `ember-cli@3.5.1` and `ember-source@3.5.1`.
- Update dependencies.

## [v0.0.9](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.9) (2018-09-25)

- Upgrade to `ember-cli@3.4.3` and `ember-source@3.4.2`.
- Update dev dependencies.

## [v0.0.8](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.8) (2018-07-03)

- Upgrade to `ember-cli@3.2.0` and `ember-source@3.2.0`.
- Update dev dependencies.
- Remove `bower.json`.

## [v0.0.7](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.7) (2018-07-03)

- Unpublished because tarball was shipped with Webstorm .idea folder.

## [v0.0.6](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.6) (2018-05-07)

- Upgrade to `ember-source@3.1.0` and dev dependencies. 

## [v0.0.5](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.5) (2018-03-06)

- Add new group by computed property.
- Private nested computed properties do not fire when changes made in array. [\#1](https://github.com/scottwernervt/ember-cli-group-by/issues/1)

## [v0.0.4](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.4) (2017-12-01)

- Upgrade to `ember-cli@2.17.0` and `ember-source@2.17.0`.

## [v0.0.3](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.3) (2017-08-22)

- Upgrade to `ember-cli@2.14.2` and `ember-source@2.14.1`.
- Use new module import code style.

## [v0.0.2](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.2) (2017-05-24)

- Remove `ember-data` as a dependency.
- Add async nested path integration tests.

## [v0.0.1](https://github.com/scottwernervt/ember-cli-group-by/tree/v0.0.1) (2017-05-23)

- Missing (default) category does not work for async relationships. [\#3](https://github.com/scottwernervt/ember-cli-group-by/issues/3)
